%"Copyright 2017 Madhusudan Govindraju"

%This program is free software: you can redistribute it and/or modify
%it under the terms of the GNU General Public License as published by
%the Free Software Foundation, either version 3 of the License, or
%(at your option) any later version.

%The Eye Tribe Tracking Toolbox is distributed in the hope that it will be useful,
%but WITHOUT ANY WARRANTY; without even the implied warranty of
%MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%GNU General Public License for more details.

%You should have received a copy of the GNU General Public License
%along with this program.  If not, see <http://www.gnu.org/licenses/>.

%Author: Madhusudan Govindraju
%Name: askQuestions
%Parameters: questionBank, responseLogFD, windowPointer
%The purpose of this function is to ask a specific set of questions and record
%the user's responses to them in the response log.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% When adding a question to the questions.txt, make sure you follow the format. %
% This serves as a templeate to ask recall type questions and save the respons- %
% es in a response log. When a question is asked we wait for the user to respond%
% by pressing an appropriate key that weill cause their response to be logged   %
% along with the response time. Then we move on to the next stimuli.            %
% This template or framework is for multiple choice questions.                  %
% The format to ask questions is available in the readme file in the main       %
% directory                                                                     %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function askQuestions(questionBank, responseLogFD, subjectNumber, windowPointer,questionNumber)
  %this lets the program know what question its on and will allow the program
  %to log only appropriate key responses.
  PATH_tosaveStimuliShown = '..\StimuliShown';
  %questionNumber = 1;
  ageQuestion = 1;
  genderQuestion = 2;
  seenBeforeQuestion = 3;
  key1 = KbName('a');
  key2 = KbName('b');
  key3 = KbName('c');
  key4 = KbName('d');
  escapeKey = KbName('ESCAPE');
  stopKey = KbName('space');
  resumeKey = KbName('r');

  fprintf(responseLogFD, '%d,', subjectNumber)
  mytext = questionBank{questionNumber};
  %[nx,ny,bbox]=DrawFormattedText(windowPointer, mytext, 'center', 'center',[255 255 255],0,0,0,4); %white text for black background
  [nx,ny,bbox]=DrawFormattedText(windowPointer, mytext, 'center', 'center',[0 0 0],0,0,0,4); %black text for gray background
  mytext2= 'Use the Keyboard to Answer the above question';
  mytext3 = 'Press Space after answering the question to continue';
  Screen('DrawText', windowPointer,mytext2 ,0 , 0, [255, 0, 0, 255]);
  Screen('DrawText', windowPointer,mytext3 ,0, 50, [255, 0, 0, 255]);
  [~, questionDisplayTime, ~] = Screen('Flip', windowPointer);
  imageArray = Screen('GetImage', windowPointer);
  varName = sprintf('Question_%d.jpg',questionNumber);
  varName = fullfile(PATH_tosaveStimuliShown,varName);
  imwrite(imageArray, varName);
  %Screen('Close',texture);
  readyForNextQuestion = 0;
  RestrictKeysForKbCheck([key1, key2, key3, key4,escapeKey,stopKey,resumeKey]);
  while(~readyForNextQuestion)
    [~,responseEnteredTime, keyCode] = KbCheck;
    responseTime = responseEnteredTime - questionDisplayTime;
    if(keyCode(key1))
        response = key1;
        keyPressed = 1;
        fprintf(responseLogFD, '%s,%d,%f,', response, keyPressed, ...
                    responseTime);
        KbReleaseWait;
    elseif (keyCode(key2))
        response = key2;
        keyPressed = 1;
        fprintf(responseLogFD, '%s,%d,%f,', response, keyPressed, ...
                    responseTime);
        KbReleaseWait;
    elseif (keyCode(key3))
        response = key3;
        keyPressed = 1;
        fprintf(responseLogFD, '%s,%d,%f,', response, keyPressed, ...
                    responseTime);
        KbReleaseWait;
    elseif(keyCode(key4))
        response = key4;
        keyPressed = 1;
        fprintf(responseLogFD, '%s,%d,%f,', response, keyPressed, ...
                    responseTime);
        KbReleaseWait;
    elseif(keyCode(stopKey))
            readyForNextQuestion = 1;
    end
  end

  %CAUTION: The final response will have an extra ',' appended to it. Since the
  %next time we want to open the file, we would like to write to a new line and
  %not start there. To do this, we will remove the ',' and append a '\r\n'
  %instead
  %The file table currently has the position set to the next byte after the
  %',' so to remove it, we should step back by one byte via a call to fseek
  byteOffset = -1;
  fseek(responseLogFD, byteOffset, 'cof');
  fprintf(responseLogFD, '\r\n');
  return
